### Name: bpca
### Title: Biplot of Multivariate Data Based on Principal Components
###   Analysis
### Aliases: bpca bpca.default bpca.prcomp
### Keywords: multivariate

### ** Examples

  ##
  ## Example 1
  ## Basic presentation and compararison with 'biplot' function ('stats' package)
  ##

  library(bpca)
  # Opening e configuring a graphical device
  x11(w=8, h=4)
  op <- par(no.readonly=TRUE)
  par(mfrow=c(1, 2))

  # Biplot of package stats (left) and bpca of package biplot (right)
  # variables in columns (represented as red vectors)
  # biplot
  biplot(prcomp(caith, scale=FALSE),
         main='biplot (stats) (scale=FALSE)')

  # bpca
  plot(bpca(caith, var.scale=FALSE),
       main='bpca - hj (var.scale=FALSE)',
       var.factor=2, var.cex=1,
       obj.cex=1)

  # Variables in rows (represented as red vectors)
  biplot(prcomp(t(caith), scale=TRUE),
         main='biplot (stats) (scale=TRUE)')

  plot(bpca(caith, var.scale=TRUE, var.pos=1),
       main='bpca - hj (var.scale=TRUE)',
       var.factor=2, var.cex=1,
       obj.cex=1)
  par(op)

  # Summarizing bpca
  summary(bpca(caith, var.scale=FALSE))
  bpca(caith, var.scale=FALSE)$coord
  bpca(caith, var.scale=FALSE)$eigenvec

  ##
  ## Example 2
  ## Computing and ploting a bpca object with 'graphics' package - 2d
  ##

  bp <- bpca(gabriel1971)

  x11(w=5, h=5)
  plot(bp, var.factor=2)

  # Exploring the object 'bp' created by the function 'bpca'
  class(bp)
  names(bp)
  str(bp)

  summary(bp)
  bp$call
  bp$eigenval
  bp$eigenvec
  bp$numb
  bp$import
  bp$coord
  bp$coord$obj
  bp$coord$var
  bp$var.rb
  bp$var.rd

  ##
  ## Example 3
  ## Computing and ploting a bpca object with 'scatterplot3d' package - 3d
  ##

  bp <- bpca(gabriel1971, lambda.end=3)

  x11(w=6, h=6)
  plot(bp, var.factor=3)

  # Exploring the object 'bp' created by the function 'bpca'
  class(bp)
  names(bp)
  str(bp)

  summary(bp)
  bp$call
  bp$eigenval
  bp$eigenvec
  bp$numb
  bp$import
  bp$coord
  bp$coord$obj
  bp$coord$var
  bp$var.rb
  bp$var.rd

  ##
  ## Example 4
  ## Computing and ploting a bpca object with 'rgl' package - 3d
  ##

  plot(bpca(gabriel1971, lambda.end=3),
       rgl.use=TRUE, var.factor=2)

  # Suggestion: Interact with the graphic with the mouse
  # left button: press, maintain and movement it to interactive rotation;
  # right button: press, maintain and movement it to interactive zoom.
  # Enjoy it!

  ##
  ## Example 5
  ## Grouping objects with different symbols and colors - 2d and 3d
  ##

  x11(w=6, h=6)

  # 2d
  plot(bpca(iris[-5]),
       var.factor=.3, var.cex=.7,
       obj.names=FALSE, obj.cex=1.5,
       obj.col=c('red', 'green3', 'blue')[unclass(iris$Species)],
       obj.pch=c('+', '*', '-')[unclass(iris$Species)])

  # 3d static
  plot(bpca(iris[-5], lambda.end=3),
       var.factor=.2, var.color=c('blue', 'red'), var.cex=1,
       obj.names=FALSE, obj.cex=1,
       obj.col=c('red', 'green3', 'blue')[unclass(iris$Species)],
       obj.pch=c('+', '*', '-')[unclass(iris$Species)])

  # 3d dinamic
  plot(bpca(iris[-5], method='hj', lambda.end=3), rgl.use=TRUE,
       var.col='brown', var.factor=.3, var.cex=1.2,
       obj.names=FALSE, obj.cex=.8,
       obj.col=c('red', 'green3', 'orange')[unclass(iris$Species)],
       simple.axes=FALSE, box=TRUE)



