### Name: plot
### Title: Biplot of Multivariate Data Based on Principal Components
###   Analysis
### Aliases: plot plot.bpca.2d plot.bpca.3d plot.qbpca
### Keywords: multivariate

### ** Examples

  ##
  ## Example 1
  ## Computing and ploting a bpca object with 'graphics' package - 2d
  ##

  library(bpca)
  bp <- bpca(gabriel1971)

  x11(w=5, h=5)
  plot(bp, var.factor=2)

  # Additional graphical parameters (nonsense)
  plot(bpca(gabriel1971, meth='sqrt'),
       main='gabriel1971 - sqrt', sub='The graphical parameters are working fine!',
       var.factor=2, var.cex=.6, var.col=rainbow(9), var.pch='v',
       obj.pch='o', obj.cex=.5, obj.col=rainbow(8), obj.pos=1, obj.offset=.5)

  ##
  ## Example 2
  ## Computing and ploting a bpca object with 'scatterplot3d' package - 3d
  ##

  bp <- bpca(gabriel1971, lambda.end=3)

  x11(w=6, h=6)
  plot(bp, var.factor=3)

  # Additional graphical parameters (nonsense)
  plot(bpca(gabriel1971, lambda.end=3, meth='jk'),
       main='gabriel1971 - jk', sub='The graphical parameters are working fine!',
       var.factor=6, var.pch='+', var.cex=.6, var.col='green4',
       obj.pch='*', obj.cex=.8, obj.col=1:8,
       ref.lty='solid', ref.col='red', angle=70)

  ##
  ## Example 3
  ## Computing and ploting a bpca object with 'rgl' package - 3d
  ##

  plot(bpca(gabriel1971, lambda.end=3),
       rgl.use=TRUE, var.factor=2)

  # Suggestion: Interact with the graphic with the mouse
  # left button: press, maintain and movement it to interactive rotation;
  # right button: press, maintain and movement it to interactive zoom.
  # Enjoy it!

  ##
  ## Example 4
  ## Grouping objects with different symbols and colors - 2d and 3d
  ##

  x11(w=6, h=6)

  # 2d
  plot(bpca(iris[-5]),
       var.factor=.3, var.cex=.7,
       obj.names=FALSE, obj.cex=1.5,
       obj.col=c('red', 'green3', 'blue')[unclass(iris$Species)],
       obj.pch=c('+', '*', '-')[unclass(iris$Species)])

  # 3d static
  plot(bpca(iris[-5], lambda.end=3),
       var.factor=.2, var.color=c('blue', 'red'), var.cex=1,
       obj.names=FALSE, obj.cex=1,
       obj.col=c('red', 'green3', 'blue')[unclass(iris$Species)],
       obj.pch=c('+', '*', '-')[unclass(iris$Species)])

  # 3d dinamic
  plot(bpca(iris[-5], method='hj', lambda.end=3), rgl.use=TRUE,
       var.col='brown', var.factor=.3, var.cex=1.2,
       obj.names=FALSE, obj.cex=.8,
       obj.col=c('red', 'green3', 'orange')[unclass(iris$Species)],
       simple.axes=FALSE, box=TRUE)

  ##
  ## Example 5
  ## Computing and ploting a bpca object with 'obj.identify=TRUE' parameter - 2d
  ##

  bp <- bpca(gabriel1971)

  # Normal labels
  if(interactive())
    plot(bp, obj.names=FALSE, obj.identify=TRUE)

  # Alternative labels
  if(interactive())
    plot(bp, obj.names=FALSE,
         obj.labels=c('toi', 'kit', 'bat', 'ele', 'wat', 'rad', 'tv', 'ref'),
         obj.identify=TRUE)

  ##
  ## Example 6
  ## Computing and ploting a bpca object with 'obj.identify=TRUE' parameter - 3d
  ##

  bp <- bpca(gabriel1971, lambda.end=3)

  # Normal labels
  if(interactive())
    plot(bp, obj.names=FALSE, obj.identify=TRUE)

  # Alternative labels
  if(interactive())
    plot(bp, obj.names=FALSE,
         obj.labels=c('toi', 'kit', 'bat', 'ele', 'wat', 'rad', 'tv', 'ref'),
         obj.identify=TRUE)



